@@ -1,7 +1,7 @@
 """
 PermissionsX - Authorization for Django.
 
-:copyright: Copyright (c) 2013 by Robert Pogorzelski.
+:copyright: Copyright (c) 2013-2014 by Robert Pogorzelski.
 :license:   BSD, see LICENSE for more details.
 
 """
@@ -17,15 +17,12 @@ from permissionsx.utils import get_class
 
 
 class PermissionsDebugPanel(DebugPanel):
+    """A django-debug-toolbar panel useful for setting up permissions."""
 
     name = 'PermissionsX'
     template = 'permissionsx/panels/permissionsx.html'
     has_content = True
 
-    def __init__(self, *args, **kwargs):
-        super(PermissionsDebugPanel, self).__init__(*args, **kwargs)
-        self._views_cache = {}
-
     def nav_title(self):
         return _('Permissions')
 
@@ -53,8 +50,9 @@ class PermissionsDebugPanel(DebugPanel):
         try:
             view_info['view_name'] = get_name_from_obj(view)
             try:
+                permissions = view.permissions_class() if callable(view.permissions_class) else view.permissions_class
                 view_info['view_permissions'] = get_name_from_obj(view.permissions_class)
-                view_info['view_rules'] = view.permissions_class().get_permissions(request)
+                view_info['view_rules'] = str(permissions.get_combined_permissions(request, *view_args, **view_kwargs))
             except AttributeError:
                 # NOTE: No permissions defined for this view.
                 pass
