@@ -1,7 +1,7 @@
 """
 PermissionsX - Authorization for Django.
 
-:copyright: Copyright (c) 2013 by Robert Pogorzelski.
+:copyright: Copyright (c) 2013-2014 by Robert Pogorzelski.
 :license:   BSD, see LICENSE for more details.
 
 """
@@ -11,21 +11,12 @@ from django.db import models
 class Profile(models.Model):
 
     user = models.ForeignKey('auth.User')
-    is_public = models.BooleanField()
+    is_public = models.BooleanField(default=False)
 
     def is_attached_to_user(self, user):
         return self.user == user
 
 
-class AnonymousProfile(object):
-
-    user = None
-    is_public = False
-
-    def is_attached_to_user(self, user):
-        return False
-
-
 class TestObject(models.Model):
 
-    title = models.CharField(max_length=50)
\ No newline at end of file
+    title = models.CharField(max_length=50)
