@@ -1,13 +1,12 @@
 """
 PermissionsX - Authorization for Django.
 
-:copyright: Copyright (c) 2013 by Robert Pogorzelski.
+:copyright: Copyright (c) 2013-2014 by Robert Pogorzelski.
 :license:   BSD, see LICENSE for more details.
 
 """
 from permissionsx.models import P
 from permissionsx.models import Permissions
-from permissionsx.tests.models import AnonymousProfile
 
 
 user_is_authenticated = P(user__is_authenticated=True)
@@ -20,8 +19,8 @@ OVERRIDE_FALSE = 'Override returns False'
 
 
 def if_override(x): return(x)
-if_true_override = lambda: if_override('Override returns True')
-if_false_override = lambda: if_override('Override returns False')
+if_true_override = lambda: if_override(OVERRIDE_TRUE)
+if_false_override = lambda: if_override(OVERRIDE_FALSE)
 
 
 class AuthenticatedPermissions(Permissions):
@@ -49,19 +48,12 @@ class AndStaffSuperuserPermissions(Permissions):
     permissions = user_is_staff & user_is_superuser
 
 
-class ProfilePermissions(Permissions):
-
-    def set_request_objects(self, request, **kwargs):
-        if request.user.is_anonymous():
-            request.user.get_profile = lambda: AnonymousProfile()
-
-
-class NegatePermissions(ProfilePermissions):
+class NegatePermissions(Permissions):
 
     permissions = ~P(user__get_profile__is_public=False) & ~P(user__is_authenticated=False)
 
 
-class IsPublicPermissions(ProfilePermissions):
+class IsPublicPermissions(Permissions):
 
     permissions = P(user__get_profile__is_public=True)
 
@@ -104,4 +96,4 @@ class NestedNegatedOverridePermissions(Permissions):
 
 class NestedNegatedPermissions(Permissions):
 
-    permissions = P(~P(user__is_authenticated=False) & P(P(user__is_authenticated=True) | ~P(user__is_authenticated=False)))
\ No newline at end of file
+    permissions = P(~P(user__is_authenticated=False) & P(P(user__is_authenticated=True) | ~P(user__is_authenticated=False)))
