@@ -1,18 +1,20 @@
 """
 PermissionsX - Authorization for Django.
 
-:copyright: Copyright (c) 2013 by Robert Pogorzelski.
+:copyright: Copyright (c) 2013-2014 by Robert Pogorzelski.
 :license:   BSD, see LICENSE for more details.
 
 """
 from django.core.urlresolvers import reverse
 from django.contrib.auth import login
 
-from permissionsx.tests.test_utils import UtilityTestCase
-from permissionsx.tests.test_utils import SettingsOverride
+from permissionsx.contrib.django import DjangoViewMixin
 from permissionsx.models import Arg
-from permissionsx.tests.permissions import *
 from permissionsx.tests.models import TestObject
+from permissionsx.tests.permissions import *
+from permissionsx.tests.test_utils import SettingsOverride
+from permissionsx.tests.test_utils import UtilityTestCase
+from permissionsx.tests.views import BaseGetView
 
 
 class PermissionsDefinitionsTests(UtilityTestCase):
@@ -58,10 +60,6 @@ class PermissionsDefinitionsTests(UtilityTestCase):
         self.assertFalse(self.permissions_for_request(AndStaffSuperuserPermissions, request_user))
         self.staff.is_superuser = True
         self.admin.is_staff = True
-        # NOTE: User must log in again if permissions changed - cleaning
-        #       cache for a specific user.
-        login(request_staff, self.staff)
-        login(request_admin, self.admin)
         self.assertTrue(self.permissions_for_request(AndStaffSuperuserPermissions, request_staff))
         self.assertTrue(self.permissions_for_request(AndStaffSuperuserPermissions, request_admin))
         self.assertFalse(self.permissions_for_request(AndStaffSuperuserPermissions, request_user))
@@ -74,7 +72,6 @@ class PermissionsDefinitionsTests(UtilityTestCase):
         self.assertFalse(self.permissions_for_request(IsPublicPermissions, request_admin))
         self.assertFalse(self.permissions_for_request(AuthenticatedPermissions, request_admin))
         self.user.get_profile().is_public = True
-        login(request_user, self.user)
         self.assertTrue(self.permissions_for_request(IsPublicPermissions, request_user))
         self.assertFalse(self.permissions_for_request(IsPublicPermissions, request_admin))
 
@@ -89,8 +86,6 @@ class PermissionsDefinitionsTests(UtilityTestCase):
         self.assertFalse(self.permissions_for_request(NegatePermissions, request_admin))
         self.user.get_profile().is_public = True
         self.admin.get_profile().is_public = True
-        login(request_user, self.user)
-        login(request_admin, self.admin)
         self.assertTrue(self.permissions_for_request(NegatePermissions, request_user))
         self.assertTrue(self.permissions_for_request(NegatePermissions, request_admin))
 
@@ -100,10 +95,8 @@ class PermissionsDefinitionsTests(UtilityTestCase):
         login(request_admin, self.admin)
         self.assertFalse(self.permissions_for_request(NestedPermissions, request_admin))
         self.admin.username = 'admin2'
-        login(request_admin, self.admin)
         self.assertFalse(self.permissions_for_request(NestedPermissions, request_admin))
         self.admin.is_staff = True
-        login(request_admin, self.admin)
         self.assertTrue(self.permissions_for_request(NestedPermissions, request_admin))
 
     def test_request_params(self):
@@ -262,3 +255,55 @@ class PermissionsDjangoViews(UtilityTestCase):
         self.login(self.client, 'staff')
         response = self.client.get(reverse('menu'), follow=True)
         self.assertContains(response, 'Staff Menu')
+
+    def test_combining_permissions(self):
+
+        class SomeBasicObjectPermissions(Permissions):
+
+            permissions = P(some_object1__title='Some Object 1')
+
+            def get_permissions(self, request, **kwargs):
+                request.some_object1 = TestObject(title='Some Object 1')
+                request.some_object2 = TestObject(title='Some Object 2')
+                request.some_object3 = TestObject(title='Some Object 3')
+                return P(some_object2__title='Some Object 2')
+
+        class SomeObjectPermissions(SomeBasicObjectPermissions):
+
+            def get_permissions(self, request, **kwargs):
+                permissions = super(SomeObjectPermissions, self).get_permissions(request, **kwargs)
+                request.some_object4 = TestObject(title='Some Object 4')
+                return permissions & P(some_object3__title='Some Object 3')
+
+        class TestView(DjangoViewMixin, BaseGetView):
+
+            permissions_class = SomeObjectPermissions(
+                P(some_object4__title='Some Object 4')
+            )
+
+        request = self.factory.get('/')
+        combined_permissions = TestView.permissions_class.get_combined_permissions(request)
+        self.assertEqual(
+            str(combined_permissions),
+            '(&{\'some_object1__title\': \'Some Object 1\'},{\'some_object4__title\': \'Some Object 4\'},{\'some_object2__title\': \'Some Object 2\'},{\'some_object3__title\': \'Some Object 3\'})'
+        )
+
+    def test_combining_permissions_with_none(self):
+
+        class SomeObjectPermissions(Permissions):
+
+            # NOTE: Inherits `permissions == None` from Permissions.
+            def get_permissions(self, request, **kwargs):
+                request.some_object = TestObject(title='Some Object')
+
+        class TestView(DjangoViewMixin, BaseGetView):
+
+            permissions_class = SomeObjectPermissions(
+                P(user_is_staff | user_is_superuser)
+            )
+
+        request = self.factory.get('/')
+        response = TestView().dispatch(request)
+        self.assertEqual(response.status_code, 200) #pylint: disable-msg=E1103
+        self.assertEqual(request.some_object.title, 'Some Object') #pylint: disable-msg=E1103
+
