@@ -1,14 +1,16 @@
 """
 PermissionsX - Authorization for Django.
 
-:copyright: Copyright (c) 2013 by Robert Pogorzelski.
+:copyright: Copyright (c) 2013-2014 by Robert Pogorzelski.
 :license:   BSD, see LICENSE for more details.
 
 """
 from django.views.generic import (
     TemplateView,
-    )
+    View,
+)
 from django.contrib import messages
+from django.http import HttpResponse
 
 from permissionsx.models import Permissions
 from permissionsx.models import P
@@ -21,6 +23,12 @@ from permissionsx.tests.permissions import (
 )
 
 
+class BaseGetView(View):
+
+    def get(self, request, *args, **kwargs):
+        return HttpResponse(str(args) + str(kwargs))
+
+
 class LoginView(TemplateView):
 
     template_name = 'tests/login.html'
